local actions = require("telescope.actions")
local action_state = require("telescope.actions.state")
local Path = require("plenary.path")
local built_in = require("telescope.builtin")

local os_sep = Path.path.sep

local is_dir = function(path)
    if Path.is_path(path) then
        return path:is_dir()
    end
    return string.sub(path, -1, -1) == os_sep
end

local create_file = function(file)
    if not file then
        return
    end
    if file == "" then
        vim.notify(
            string.format("[file_browser.%s] %s", "actions.create", "Please enter a valid file or folder name!"),
            vim.log.levels.WARN,
            {
                title = "telescope-file-browser.nvim",
            }
        )
        return
    end
    file = Path:new(file)
    if file:exists() then
        vim.notify(
            string.format("[file_browser.%s] %s", "actions.create", "Selection already exists!"),
            vim.log.levels.WARN,
            {
                title = "telescope-file-browser.nvim",
            }
        )
        return
    end

    if not is_dir(file.filename) then
        file:touch({ parents = true })
    else
        Path:new(file.filename:sub(1, -2)):mkdir({ parents = true, mode = 493 }) -- 493 => decimal for mode 0755
    end

    return file
end
local get_dropdown = require("telescope.themes").get_dropdown
local tnf = function()
    built_in.find_files(get_dropdown({
        previewer = false,
        find_command = { "find", ".", "-type", "d", "-not", "-path", "*/node_modules/*" },
        attach_mappings = function(prompt_bufnr)
            actions.select_default:replace(function()
                local current_picker = action_state.get_current_picker(prompt_bufnr)
                local entry = action_state.get_selected_entry()
                if entry then
                    local base_dir = action_state.get_selected_entry().value .. os_sep
                    current_picker:reset_prompt(base_dir, true)
                else
                    local file_path = current_picker:_get_prompt()
                    actions.close(prompt_bufnr)
                    local file = create_file(file_path)
                    if file then
                        vim.cmd.edit(file:absolute())
                    end
                end
            end)
            return true
        end,
    }))
end

return require("telescope").register_extension({
    exports = {
        tnf = tnf,
    },
})
